@@ -15,18 +15,14 @@ from django.forms import Widget, Media
 class JSONWidget(Widget):
     """
     JSON 表单组件
+    https://github.com/josdejong/jsoneditor
     """
     template_name = 'django_kelove_db/forms/json.html'
 
-    json_editor_config = {
-        "mode": "code",
-        "modes": ["code", "form", "text", "tree", "view", "preview"],
-    }
-
     def __init__(self, attrs=None):
         if attrs is None:
             attrs = {}
-        attrs['json_editor_config'] = json.dumps({**self.json_editor_config, **attrs.get('json_editor_config', {})})
+        attrs['field_settings'] = json.dumps(attrs.get('field_settings', {}))
         super().__init__(attrs)
 
     def _get_media(self):
@@ -36,3 +32,25 @@ class JSONWidget(Widget):
         )
 
     media = property(_get_media)
+
+
+class EditorMdWidget(Widget):
+    """
+    EditorMd 表单组件
+    https://github.com/pandao/editor.md
+    """
+    template_name = 'django_kelove_db/forms/editor_md.html'
+
+    def __init__(self, attrs=None):
+        if attrs is None:
+            attrs = {}
+        attrs['field_settings'] = json.dumps(attrs.get('field_settings', {}))
+        super().__init__(attrs)
+
+    def _get_media(self):
+        return Media(
+            css={"all": ('django_kelove_db/editor_md/css/editormd.min.css',)},
+            js=('django_kelove_db/jquery/jquery-3.5.1.min.js', 'django_kelove_db/editor_md/editormd.min.js')
+        )
+
+    media = property(_get_media)
